@@ -49,10 +49,13 @@ class DFPermission(BasePermission):
             serializer = view.get_serializer()
             serializer_fields = list(serializer.fields.keys())
 
-            model_fields = self._get_model_fields(view)
-
-            # get fields only available in model
-            fields = [field for field in serializer_fields if field in model_fields]
+            # version >= 0.1.6 (available for serializer fields)
+            fields = serializer_fields
+            # version < 0.1.6
+            # model_fields = self._get_model_fields(view)
+            #
+            # # get fields only available in model
+            # fields = [field for field in serializer_fields if field in model_fields]
         else:
             raise AttributeError('df_fields is required')
 
